#if !defined(AFX_GEOPANEL_H__FE700176_8AFC_484B_BF04_1D0A80D19F43__INCLUDED_)
#define AFX_GEOPANEL_H__FE700176_8AFC_484B_BF04_1D0A80D19F43__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// GeoPanel.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CGeoPanel dialog

namespace Stuff
{
class Page;
};

class CGeoPanel : public CDialog
{
// Construction
public:
	bool ValidateEntries();
	CGeoPanel(CWnd* pParent = NULL);   // standard constructor
	void WriteEntries(Stuff::Page *page);
	float GetLowHFVal() {return LowHFVal;}
	float LowHFVal;
	int HFX,HFY,
		ZoneCountX,ZoneCountY;

	// Dialog Data
	//{{AFX_DATA(CGeoPanel)
	enum { IDD = IDD_GEOMETRY_PANEL };
	CString m_HFEdit;
	CSliderCtrl	m_SPassCon;
	float	m_HScale;
	int		m_SPasses;
	int		m_PolyCount;
	BOOL	m_FinalPass;
	BOOL	m_InterestData;
	int		m_TriCap;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CGeoPanel)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CGeoPanel)
	virtual void OnOK() {}
	virtual void OnCancel() {}
	virtual BOOL OnInitDialog();
	afx_msg void OnHfbrowse();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_GEOPANEL_H__FE700176_8AFC_484B_BF04_1D0A80D19F43__INCLUDED_)
